==> eslint-plugin-jsx-a11y-1.0.2.tgz: package/lib/rules/mouse-events-have-key-events.js <==
/**
 * @fileoverview Enforce onmouseover/onmouseout are
 *  accompanied by onfocus/onblur.
 * @author Ethan Cohen
 */
'use strict';

// ----------------------------------------------------------------------------
// Rule Definition
// ----------------------------------------------------------------------------

var _getAttribute = require('../util/getAttribute');

var _getAttribute2 = _interopRequireDefault(_getAttribute);

var _getAttributeValue = require('../util/getAttributeValue');

var _getAttributeValue2 = _interopRequireDefault(_getAttributeValue);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var mouseOverErrorMessage = 'onMouseOver must be accompanied by onFocus for accessibility.';
var mouseOutErrorMessage = 'onMouseOut must be accompanied by onBlur for accessibility.';

module.exports = function (context) {
  return {
    JSXOpeningElement: function JSXOpeningElement(node) {
      var attributes = node.attributes;

      // Check onmouseover / onfocus pairing.
      var onMouseOver = (0, _getAttribute2.default)(attributes, 'onMouseOver');
      var onMouseOverValue = (0, _getAttributeValue2.default)(onMouseOver);

      if (onMouseOver && (onMouseOverValue !== null || onMouseOverValue !== undefined)) {
        var hasOnFocus = (0, _getAttribute2.default)(attributes, 'onFocus');
        var onFocusValue = (0, _getAttributeValue2.default)(hasOnFocus);

        if (hasOnFocus === false || onFocusValue === null || onFocusValue === undefined) {
          context.report({
            node: node,
            message: mouseOverErrorMessage
          });
        }
      }

      // Checkout onmouseout / onblur pairing
      var onMouseOut = (0, _getAttribute2.default)(attributes, 'onMouseOut');
      var onMouseOutValue = (0, _getAttributeValue2.default)(onMouseOut);
      if (onMouseOut && (onMouseOutValue !== null || onMouseOutValue !== undefined)) {
        var hasOnBlur = (0, _getAttribute2.default)(attributes, 'onBlur');
        var onBlurValue = (0, _getAttributeValue2.default)(hasOnBlur);

        if (hasOnBlur === false || onBlurValue === null || onBlurValue === undefined) {
          context.report({
            node: node,
            message: mouseOutErrorMessage
          });
        }
      }
    }
  };
};

module.exports.schema = [{ type: 'object' }];

==> eslint-plugin-jsx-a11y-1.4.0.tgz: package/lib/rules/mouse-events-have-key-events.js <==
/**
 * @fileoverview Enforce onmouseover/onmouseout are
 *  accompanied by onfocus/onblur.
 * @author Ethan Cohen
 */
'use strict';

// ----------------------------------------------------------------------------
// Rule Definition
// ----------------------------------------------------------------------------

var _jsxAstUtils = require('jsx-ast-utils');

var mouseOverErrorMessage = 'onMouseOver must be accompanied by onFocus for accessibility.';
var mouseOutErrorMessage = 'onMouseOut must be accompanied by onBlur for accessibility.';

module.exports = function (context) {
  return {
    JSXOpeningElement: function JSXOpeningElement(node) {
      var attributes = node.attributes;

      // Check onmouseover / onfocus pairing.
      var onMouseOver = (0, _jsxAstUtils.getProp)(attributes, 'onMouseOver');
      var onMouseOverValue = (0, _jsxAstUtils.getPropValue)(onMouseOver);

      if (onMouseOver && (onMouseOverValue !== null || onMouseOverValue !== undefined)) {
        var hasOnFocus = (0, _jsxAstUtils.getProp)(attributes, 'onFocus');
        var onFocusValue = (0, _jsxAstUtils.getPropValue)(hasOnFocus);

        if (hasOnFocus === false || onFocusValue === null || onFocusValue === undefined) {
          context.report({
            node: node,
            message: mouseOverErrorMessage
          });
        }
      }

      // Checkout onmouseout / onblur pairing
      var onMouseOut = (0, _jsxAstUtils.getProp)(attributes, 'onMouseOut');
      var onMouseOutValue = (0, _jsxAstUtils.getPropValue)(onMouseOut);
      if (onMouseOut && (onMouseOutValue !== null || onMouseOutValue !== undefined)) {
        var hasOnBlur = (0, _jsxAstUtils.getProp)(attributes, 'onBlur');
        var onBlurValue = (0, _jsxAstUtils.getPropValue)(hasOnBlur);

        if (hasOnBlur === false || onBlurValue === null || onBlurValue === undefined) {
          context.report({
            node: node,
            message: mouseOutErrorMessage
          });
        }
      }
    }
  };
};

module.exports.schema = [{ type: 'object' }];
